<template>
  <el-container class="layout-container flex-center">
    <LayoutHeader />
    <el-container class="layout-mian-height-50">
      <LayoutAside />
      <div class="flex-center layout-backtop">
        <LayoutTagsView v-if="isTagsview" />
        <LayoutMain ref="layoutMainRef" />
      </div>
    </el-container>
  </el-container>
</template>

<script setup lang="ts" name="layoutClassic">
import { defineAsyncComponent, computed, nextTick, ref, watch, onMounted } from 'vue'
import { useRoute } from 'vue-router'
import { storeToRefs } from 'pinia';
import { useThemeConfig } from '/@/stores/themeConfig'
// 引入组件
const LayoutAside = defineAsyncComponent(() => import('/@/layout/component/aside.vue'));
const LayoutHeader = defineAsyncComponent(() => import('/@/layout/component/header.vue'));
const LayoutMain = defineAsyncComponent(() => import('/@/layout/component/main.vue'));
const LayoutTagsView = defineAsyncComponent(() => import('/@/layout/navBars/tagsView/tagsView.vue'));

// 定义变量内容
type LayoutMainType = InstanceType<typeof LayoutMain>;//定义LayoutMain组件实例类型--知识点55
const layoutMainRef = ref<LayoutMainType>()//InstanceType<typeof C>: 常用于给  某个子组件组件实例 获取对应类型

const route = useRoute();//获取原生路由对象

const storesThemeConfig = useThemeConfig()
// console.log(storesThemeConfig)
// console.log(storeToRefs(storesThemeConfig))
const { themeConfig } = storeToRefs(storesThemeConfig)//pinia的storeToRefs解构赋值是响应式
// 判断是否显示 tasgview
const isTagsview = computed(() => {
  return themeConfig.value.isTagsview
})

// 重置滚动条高度，更新子级 scrollbar
const updateScrollbar = () => {
  layoutMainRef.value?.layoutMainScrollbarRef.update()
}

// 重置滚动条高度，由于组件是异步引入的
const initScrollBarHeight = () => {
  nextTick(() => {
    setTimeout(() => {
      updateScrollbar();
      console.log(layoutMainRef.value!.layoutMainScrollbarRef)
      layoutMainRef.value!.layoutMainScrollbarRef.wrap$.scrollTop = 0; // '!' not null 断言操作符，不执行运行时检查
    }, 500);
  })
}
// 页面加载时
onMounted(() => {
  initScrollBarHeight()
})

//监听路由的变化，切换界面，滚动条置顶
watch(() => route.path, () => { initScrollBarHeight })
//监听themeConfig配置文件的变化，更新菜单el-scrollbar的高度
watch(themeConfig, () => { updateScrollbar() }, { deep: true })//deep:true深入递归监听配置文件
</script>
<style lang='scss' scoped></style>